from bs4 import BeautifulSoup

from .prune import Pruned


def divisions(text: str):
    """ Slice body based on unique hr tags, previously added by divider functions """
    html = BeautifulSoup(text, "html5lib")
    for hr in html("hr"):
        initiator = str(hr)  # unique 1
        start = text.index(initiator)
        if not (e := hr.find_next("hr")):
            continue
        terminator = str(e)  # unique 2
        end = text.index(terminator)
        yield text[start:end]


def get_annex(text: str):
    """
    Can the content be divided into parts after the ponencia? (postcorpus)
    Retrieve the annex of the ponencia, excluding extraneous content (prune)
    Should result in a single string of text consisting of <sup> tags, e.g.
    <sup>[1]</sup> Footnote value;
    <sup>[2]</sup> Footnote value;
    """
    if not text:
        return None
    elif not (parts := list(divisions(text))):
        return None
    elif not (annex := Pruned(parts).top_of_queue):
        return None
    return annex
