import re
from typing import Optional, Tuple

from lxml import etree


def get_writer(raw: Optional[str]) -> Optional[str]:
    if not raw:
        return None
    judge = r"(\,?\s*\bJ\s*(\.|\:))"
    chief = r"(\,?\s*\bC\.?\s*J\s*(\.|\:))"
    upper_curiam = r"(\bCURIAM\b)"
    title_curiam = r"(\bCuriam\b)"
    patterns = [judge, chief, upper_curiam, title_curiam]
    options = rf"({'|'.join(patterns)})"
    pattern = re.compile(options)
    return raw if pattern.search(raw) else None


def clean_writer(text: str):
    text = text.removesuffix(" J.:*")
    text = text.removesuffix("[*]")
    text = text.removesuffix(", J:")
    text = text.removesuffix(", J:")
    text = text.removesuffix(", J.:")
    text = text.removesuffix(", C.J.:")
    text = text.removesuffix(":")
    return text.title()


def spot_writer(text: str) -> Tuple[Optional[str], Optional[str]]:
    WRITER = "//strong[1]/text()"
    html = etree.HTML(text)

    if not (raw := html.xpath(WRITER)[0]):
        return None, None

    if not (writer := str(raw)):
        return None, None

    if not (uncleaned := get_writer(writer)):
        return None, None

    return str(raw), clean_writer(uncleaned)
